<?php
$lang['error_feu_loggedin'] = 'L&#039;utente non ha effettuato il login in FEU.  Non &egrave; permesso aggiungere o modificare eventi';
$lang['prompt_friendlyname'] = 'Nome semplice per questo modulo nella navigazione lato amministratore';
$lang['info_friendlyname'] = 'Nota bene: E&#039; possibile che sia necessario cancellare la cache perch&egrave; quest&#039;opzione abbia effetto. Se non viene inserito alcun valore ne verr&agrave; utilizzato uno predefinito.';
$lang['use_wysiwyg'] = 'Usa editor Wysiwyg';
$lang['error_insufficientparams'] = 'Paramentri Insufficienti';
$lang['column_delimiter'] = 'Delimitatore di colonna del file importato';
$lang['import_completed'] = 'Importazione Completata';
$lang['num_imported'] = 'Numero di eventi creati: %d';
$lang['import_lines'] = 'Numero di linee elaborate dal file: %d';
$lang['errors'] = 'Errori';
$lang['error_csvfirstlineinvalidfield'] = 'Campo: %s non &egrave; stato riconosciuto e non &egrave; un campo personalizzato';
$lang['info_csv_format'] = '<h4>Informazioni sul formato CSV.</h4>
<ul>
  <li>Informazioni Generali:
   <ul>
     <li>Il file dev&#039;essere di tipo ASCII con fine linea di tipo unix, dos, o mac.</li>
     <li>I commenti iniziano con // <br />Ogni carattere dopo questi su una riga verranno ignorati (compresi quelli tra virgolette e apici).</li>
     <li>Le linee vuote vengono ignorate.</li>
     <li>I campi sono delimitati da &quot;,&quot;, tuttavia una &quot;,&quot; pu&ograve; essere utilizzata come valore all&#039;interno di un campo se il campo &egrave; delimitato da virgolette.</li>
     <li>Le Righe sono delimitate da caratteri di interruzione di linea (come sopra).</li>
   </ul>
  </li>
  <li>The Field Map:
   <ul>
    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
   </ul>
  </li>
  <li>The Data Rows:
   <ul>
    <li>The start time, title, and description fields must not be empty.</li>
<li>Start and End Times:</li>
  <ul>
   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
   <li>If the end time column is empty, then no end time value will be created in the database.</li>
  </ul>
</li>
<li>Categories
  <ul>
   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
   <li>Category names are case sensitive.</li>
   <li>Categories are not created if they do not exist.</li>
  </ul>
</li>
<li>Custom Fields:
  <ul>
    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
  </ul>
  </li>
  </ul>
</li>
<li>A sample csv file exists in the modules source code directory.</li>
</ul>';
$lang['prompt_csv_file'] = 'Selezionare File da Importare';
$lang['delete'] = 'Elimina';
$lang['cd_company'] = 'Azienda Directory Company';
$lang['dflt_urlprefix'] = 'Prefisso URL predefinito per Pretty URL';
$lang['dflt_alldayevent'] = 'I nuovi eventi sono &quot;Tutto il giorno&quot; di default';
$lang['dflt_starttime'] = 'Ora di inizio predefinita per i nuovi eventi';
$lang['info_dflt_starttime'] = '<em>(si applica solo se i nuovi eventi non sono &quot;Tutto il giorno&quot;.)</em>';
$lang['search_type'] = 'Cerca Tipo';
$lang['search_any'] = 'Corrispondenza di qualsiasi termine';
$lang['search_all'] = 'Corrispondenza di tutti i termini';
$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Nota:</span> I Campi di Caricamento File non sono ricercabili.';
$lang['searchable'] = 'Ricercabile';
$lang['help_param_editeventtemplate'] = 'Applicabile solo all&#039;azione &quot;myevents&quot;, questo parametro permette di specificare un modello di modifica evento non predefinito quando un utente crea o modifica un evento';
$lang['help_param_editpage'] = 'Applicabile solo all&#039;azione &quot;myevent&quot;, questo parametro permette di specificare una pagina differente per il modulo di modifica.';
$lang['help_param_myeventstemplate'] = 'Applicabile solo all&#039;azione &quot;myevent&quot;, questo parametro permette di specificare l&#039;uso di un modello non predefinito';
$lang['cal_edit_event'] = 'Modifica Evento Calendario';
$lang['error_dberror'] = 'Errore del Database';
$lang['submit'] = 'Invia';
$lang['info_sysdflt_editevent_template'] = 'Modello Predefinito di Sistema &quot;Modifica Evento&quot;';
$lang['info_sysdflt_myevents_template'] = 'Modello Predefinito di Sistema &quot;Miei Eventi&quot;';
$lang['prompt_feedit_group'] = 'I membri di questo gruppo FEU possono aggiungere eventi';
$lang['prompt_feedit_page'] = 'Pagina predefinita lato utente per il modulo di modifica.';
$lang['none'] = 'Nessuno';
$lang['owner'] = 'Proprietario';
$lang['cal_editevent_templates'] = 'Modelli del Modulo di Modifica Evento';
$lang['info_editevent_template_tab'] = 'La lista dei modelli disponibili per il modulo di modifica evento';
$lang['editeventtemplate_addedit'] = 'Aggiungi/modifica un Modello Modulo di Modifica Evento';
$lang['cal_myevents_templates'] = 'Modelli di Lista Miei Eventi';
$lang['info_myevents_template_tab'] = 'La lista dei modelli disponibili per la visualizzazione di una lista di eventi dell&#039;utente';
$lang['myeventstemplate_addedit'] = 'Aggiungi/Modifica un modello di report &quot;Miei Eventi&quot;';
$lang['areyousure_removeconflicting'] = 'Questa azione rimuover&agrave; ogni evento in conflitto con eventi non sovrapponibili. Siete certi di volere procedere?';
$lang['filter_conflicting'] = 'Filtra Eventi in Conflitto';
$lang['overlap_action_remove'] = 'Rimuovi eventi in conflitto silenziosamente';
$lang['overlap_action_error'] = 'Visualizza un errore';
$lang['prompt_overlap_action'] = 'Cosa dovrebbe accadere quando viene trovato un conflitto durante l&#039;aggiunta o la modifica di un evento';
$lang['error_event_conflict'] = 'I valori dell&#039;evento specificato si sovrappongono con un evento esistente che non permette conflitti';
$lang['cal_info_overlap'] = 'Si applica solo agli eventi con una data di fine (o eventi giornalieri)';
$lang['cal_overlap'] = 'Permette la sovrapposizione di nuovi eventi con il corrente';
$lang['prompt_overlap_policy'] = 'Gestione Sovrapposizione Eventi';
$lang['policy_all'] = 'Tutti gli eventi si possono sovrapporre';
$lang['policy_none'] = 'Nessun evento si pu&ograve; sovrapporre';
$lang['policy_individual'] = 'Definito evento per evento';
$lang['lbl_back'] = 'Indietro';
$lang['lbl_templates'] = 'Modelli';
$lang['textarea'] = 'Area di Testo';
$lang['error_calendar_incompatible'] = 'Abbiamo verificato la presenza anche del modulo Calendar. Questo modulo non &egrave; compatibile con il modulo Calendar e i due non possono coesistere nella stessa installazione. Vi chiediamo di disinstallare il modulo Calendar.';
$lang['error_event_not_found'] = 'Event_id non presente nel database, oppure c&#039;&egrave; pi&ugrave; di un evento con questo id! (%d)';
$lang['first_page'] = '<<';
$lang['prev_page'] = '<';
$lang['next_page'] = '>';
$lang['last_page'] = '>>';
$lang['page_of'] = 'Pagina %d di %d';
$lang['search_results'] = 'Risultati Ricerca Calendario';
$lang['search_words'] = 'Cerca Parole';
$lang['no_results_found'] = 'Nessun risultato in base ai criteri specificati';
$lang['frequency'] = 'Frequenza';
$lang['specified_date'] = 'Usa la data specificata';
$lang['first_sunday'] = 'Prima Domenica del Mese';
$lang['first_monday'] = 'Primo Luned&igrave; del Mese';
$lang['first_tuesday'] = 'Primo Marted&igrave; del Mese';
$lang['first_wednesday'] = 'Primo Mercoled&igrave; del Mese';
$lang['first_thursday'] = 'Primo Gioved&igrave; del Mese';
$lang['first_friday'] = 'Primo Venerd&igrave; del Mese';
$lang['first_saturday'] = 'Primo Sabato del Mese';
$lang['second_sunday'] = 'Seconda Domenica del Mese';
$lang['second_monday'] = 'Secondo Luned&igrave; del Mese';
$lang['second_tuesday'] = 'Secondo Marted&igrave; del Mese';
$lang['second_wednesday'] = 'Secondo Mercoled&igrave; del Mese';
$lang['second_thursday'] = 'Secondo Gioved&igrave; del Mese';
$lang['second_friday'] = 'Secondo Venerd&igrave; del Mese';
$lang['second_saturday'] = 'Secondo Sabato del Mese';
$lang['third_sunday'] = 'Terza Domenica del Mese';
$lang['third_monday'] = 'Terzo Luned&igrave; del Mese';
$lang['third_tuesday'] = 'Terzo Marted&igrave; del Mese';
$lang['third_wednesday'] = 'Terzo Mercoled&igrave; del Mese';
$lang['third_thursday'] = 'Terzo Gioved&igrave; del Mese';
$lang['third_friday'] = 'Terzo Venerd&igrave; del Mese';
$lang['third_saturday'] = 'Terzo Sabato del Mese';
$lang['fourth_sunday'] = 'Quarta Domenica del Mese';
$lang['fourth_monday'] = 'Quarto Luned&igrave; del Mese';
$lang['fourth_tuesday'] = 'Quarto Marted&igrave; del Mese';
$lang['fourth_wednesday'] = 'Quarto Mercoled&igrave; del Mese';
$lang['fourth_thursday'] = 'Quarto Gioved&igrave; del Mese';
$lang['fourth_friday'] = 'Quarto Venerd&igrave; del Mese';
$lang['fourth_saturday'] = 'Quarto Sabato del Mese';
$lang['last_sunday'] = 'Ultima Domenica del Mese';
$lang['last_monday'] = 'Ultimo Luned&igrave; del Mese';
$lang['last_tuesday'] = 'Ultimo Marted&igrave; del Mese';
$lang['last_wednesday'] = 'Ultimo Mercoled&igrave; del Mese';
$lang['last_thursday'] = 'Ultimo Gioved&igrave; del Mese';
$lang['last_friday'] = 'Ultimo Venerd&igrave; del Mese';
$lang['last_saturday'] = 'Ultimo Sabato del Mese';
$lang['error_invalid_recur_monthly_freq'] = 'Frequenza non valida... non potete utilizzare sia la data specifica che altri valori';
$lang['searchresulttemplate_addedit'] = 'Aggiungi/Modifica un Modello di Risultato Ricerca';
$lang['info_searchresult_template_tab'] = 'La lista dei Modelli che sono disponibili per la visualizzazione dei risultati di ricerca';
$lang['info_sysdflt_searchresult_template'] = 'Modello di Risultato Ricerca Predefinito di Sistema';
$lang['cal_search_result_templates'] = 'Modelli di Risultato Ricerca';
$lang['error_query_failed'] = 'Interrogazione Database Fallita';
$lang['error_search_invalid_dates'] = 'Date di ricerca specificate non valide';
$lang['text'] = 'Testo';
$lang['search'] = 'Cerca';
$lang['category'] = 'Categoria';
$lang['info_sysdflt_search_template'] = 'Modello di Modulo di Ricerca Predefinito di Sistema';
$lang['searchtemplate_addedit'] = 'Aggiungi/Modifica Modello Modulo di Ricerca';
$lang['info_search_template_tab'] = 'La lista dei modelli che sono disponibili per il modulo di ricerca';
$lang['cal_search_form_templates'] = 'Modelli Modulo Ricerca';
$lang['max'] = 'massimo';
$lang['times'] = 'volte';
$lang['on'] = 'a';
$lang['areyousure_uninstall'] = 'Siete sicuri di volere procedere? Continuando cancellerete permanentemente tutti i dati associati a questo modulo.';
$lang['post_uninstall'] = 'Il modulo Calendar &egrave; stato disinstallato e sono stati rimossi tutti gli eventi ed i template associati con questo modulo';
$lang['fieldupdated'] = 'Campo aggiornato';
$lang['every'] = 'Ogni';
$lang['or'] = 'o';
$lang['update_children'] = 'Aggiorna gli Eventi figli';
$lang['error_nocategory'] = 'Dovete selezionare almeno una categoria';
$lang['error_nothingselected'] = 'Non &egrave; stato selezionato nulla per la cancellazione';
$lang['error_eventoverlap'] = 'I parametri di ripetizione degli eventi che avete specificato potrebbero risultare in una sovrapposizione di eventi.';
$lang['recurs'] = 'Ricorre';
$lang['error_invalid_dates'] = 'Uno o pi&ugrave; valori di data inseriti erano invalidi';
$lang['sunday'] = 'Domenica';
$lang['monday'] = 'Luned&igrave;';
$lang['tuesday'] = 'Marted&igrave;';
$lang['wednesday'] = 'Mercoled&igrave;';
$lang['thursday'] = 'Gioved&igrave;';
$lang['friday'] = 'Venerd&igrave;';
$lang['saturday'] = 'Sabato';
$lang['abbr_sunday'] = 'Do';
$lang['abbr_monday'] = 'Lu';
$lang['abbr_tuesday'] = 'Ma';
$lang['abbr_wednesday'] = 'Me';
$lang['abbr_thursday'] = 'Gi';
$lang['abbr_friday'] = 'Ve';
$lang['abbr_saturday'] = 'Sa';
$lang['weekdays'] = 'Giorni settimana';
$lang['plural_daily'] = 'Giorni';
$lang['plural_weekly'] = 'Settimane';
$lang['plural_monthly'] = 'Mesi';
$lang['plural_yearly'] = 'Anni';
$lang['no'] = 'No';
$lang['daily'] = 'Giornalmente';
$lang['weekly'] = 'Settimanalmente';
$lang['monthly'] = 'Mensilmente';
$lang['yearly'] = 'Annualmente';
$lang['interval'] = 'Ripeti ogni';
$lang['cal_recur_details'] = 'Dettaglio evento ricorrente';
$lang['unlimited'] = 'Non limitato';
$lang['max_recur_events'] = 'Massimo numero di eventi figli';
$lang['use_to_date'] = 'Specificare data di fine diversa?';
$lang['cancel'] = 'Cancella';
$lang['show_child_events'] = 'Mostra Eventi figli <em>(potrebbe restituire una schermata molto lunga)</em>';
$lang['n/a'] = 'n/d';
$lang['recurs_until'] = 'Ripeti fino';
$lang['parent'] = 'Genitore';
$lang['recur_period'] = 'Periodo di ricorsione';
$lang['filter'] = 'Filtro';
$lang['start_date'] = 'Data partenza';
$lang['end_date'] = 'Data arrivo';
$lang['info_upcominglist_template_tab'] = 'La lista dei template che sono utilizzabili per gli eventi imminenti';
$lang['upcominglisttemplate_addedit'] = 'Aggiungi/Modifica un Modello per la visualizzazione Upcominglist (prossimi eventi)';
$lang['info_sysdflt_upcominglist_template'] = 'Modello Predefinito di Sistema per la visualizzazione Upcominglist (prossimi eventi)';
$lang['info_list_template_tab'] = 'La lista dei modelli che sono disponibili per la vista di liste';
$lang['listtemplate_addedit'] = 'Aggiungi/Modifica un Modello per la visualizzazione List (lista)';
$lang['info_sysdflt_list_template'] = 'Modello Predefinito di Sistema per la visualizzazione List (lista)';
$lang['info_event_template_tab'] = 'La lista dei modelli che sono disponibili per la vista di eventi';
$lang['eventtemplate_addedit'] = 'Aggiungi/Modifica un Modello per la visualizzazione Event (evento)';
$lang['info_sysdflt_event_template'] = 'Modello Predefinito di Sistema per la visualizzazione Event (evento)';
$lang['info_calendar_template_tab'] = 'La lista dei modelli che sono disponibili per la vista di calendari';
$lang['calendartemplate_addedit'] = 'Aggiungi/Modifica un Modello per la visualizzazione Calendar (calendario)';
$lang['info_sysdflt_calendar_template'] = 'Modello Predefinito di Sistema per la visualizzazione Calendar (calendario)';
$lang['info_sysdflt_template'] = 'Questo modulo definisce il modello che sar&agrave; utilizzato quando cliccate su &quot;Nuovo Modello&quot; nella scheda appropriata.  Modificare questo valore non avr&agrave; effetti immediati sulle visualizzazioni generate da questo modulo.';
$lang['eventdesc-EventAdded'] = 'Chiamato dopo aver aggiunto un evento al calendario';
$lang['eventdesc-EventEdited'] = 'Chiamato dopo aver modificato un evento esistente';
$lang['eventdesc-EventDeleted'] = 'Chiamato dopo aver eliminato un evento';
$lang['eventdesc-CategoryAdded'] = 'Chiamato dopo la creazione di una categoria';
$lang['eventdesc-CategoryEdited'] = 'Chiamato dopo aver modificato una categoria';
$lang['eventdesc-CategoryDeleted'] = 'Chiamato dopo aver eliminato una categoria';
$lang['eventhelp-EventAdded'] = '<p>Inviato quando viene aggiunto un evento al calendario.</p>
<h4>Parameteri</h4>
<ul>
<li>\&quot;event_title\&quot; - Titolo evento</li>
<li>\&quot;event_summary\&quot; - Sommario</li>
<li>\&quot;event_details\&quot; - Dettaglio</li>
<li>\&quot;event_date_start\&quot; - Data e ora dell&#039;inizio dell&#039;evento</li>
<li>\&quot;event_date_end\&quot; - Data e ora della fine dell&#039;evento</li>
<li>\&quot;event_created_by\&quot; - La userid dell&#039;autore</li>
<li>\&quot;event_id\&quot; - id dell&#039;evento</li>
</ul>
';
$lang['eventhelp-EventEdited'] = '<p>Inviato quando viene modificato un evento esistente.</p>
<h4>Parameteri</h4>
<ul>
<li>\&quot;event_title\&quot; - Titolo evento</li>
<li>\&quot;event_summary\&quot; - Sommario</li>
<li>\&quot;event_details\&quot; - Dettaglio</li>
<li>\&quot;event_date_start\&quot; - Data e ora dell&#039;inizio dell&#039;evento</li>
<li>\&quot;event_date_end\&quot; - Data e ora della fine dell&#039;evento</li>
<li>\&quot;event_created_by\&quot; - La userid dell&#039;autore</li>
<li>\&quot;event_id\&quot; - id dell&#039;evento</li>
</ul>
';
$lang['eventhelp-EventDeleted'] = '<p>Inviato quando viene eliminato un evento.</p>
<h4>Parameteri</h4>
<ul>
<li>\&quot;event_id\&quot; - id dell&#039;evento</li>
</ul>
';
$lang['eventhelp-CategoryAdded'] = '<p>Inviato quando viene aggiunta una categoria.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - id della categoria</li>
</ul>
';
$lang['eventhelp-CategoryEdited'] = '<p>Inviato quando viene modificata una categoria.</p>
<h4>Parameteri</h4>
<ul>
<li>\&quot;category_id\&quot; - id della categoria</li
<li>\&quot;category_name\&quot; - Nome della categoria</li>
<li>\&quot;category_order\&quot; - Posizione della categoria nell&#039;ordinamento</li>
</ul>
';
$lang['eventhelp-CategoryDeleted'] = '<p>Inviato quando viene eliminata una categoria.</p>
<h4>Parameteri</h4>
<ul>
<li>\&quot;category_id\&quot; - id della categoria</li
<li>\&quot;category_name\&quot; - Nome della categoria</li>
<li>\&quot;category_order\&quot; - Posizione della categoria nell&#039;ordinamento</li>
</ul>
';
$lang['error_csv_insert'] = 'Errore durante l&#039;importazione di eventi da csv alla linea %d';
$lang['error_csvfirstlinefldnotfound'] = 'Un campo richiesto ( %s ) non &egrave; stato trovato nella riga di intestazione del file csv';
$lang['error_csvinvalidfirstline'] = 'Non &egrave; possibile individuare una prima riga valida nel file CSV';
$lang['msg_eventadded'] = 'Evento aggiunto';
$lang['error_noeventname'] = 'Un nome per l&#039;evento &egrave; richiesto';
$lang['error_noupload'] = 'ERRORE: Non &egrave; stato trovato alcun file caricato';
$lang['error_invalidfilename'] = 'ERRORE: Il file caricato non pu&ograve; essere accettato';
$lang['error_problemwithupload'] = 'ERRORE: E&#039; avvenuto un problema durante il caricamento del file ';
$lang['error_filecopyfailed'] = 'ERRORE: E&#039; avvenuto un problema mentre il file veniva copiato nella sua destinazione finale';
$lang['error_fileexists'] = 'ERRORE: Esiste gi&agrave; un file con quel nome';
$lang['error_csvfilenotfound'] = 'ERRORE: Non posso trovare il file CSV';
$lang['error_cantopenfile'] = 'ERRORE: Non posso aprire il file';
$lang['error_categoryexists'] = 'ERRORE: Una categoria con il nome %s gi&agrave; esiste';
$lang['cal_id'] = 'ID';
$lang['cal_calendar'] = 'Calendario';
$lang['cal_default_templates'] = 'Template predefiniti';
$lang['cal_description'] = 'Aggiunge, modifica e rimuove eventi';
$lang['cal_addevent'] = 'Aggiungi Eventi';
$lang['cal_import_events'] = 'Importa Eventi';
$lang['cal_events'] = 'Eventi';
$lang['cal_categories'] = 'Categorie';
$lang['cal_calendar_template'] = 'Modello del calendario';
$lang['cal_list_template'] = 'Modello della lista';
$lang['cal_upcominglist_template'] = 'Modello di evento imminente';
$lang['cal_event_template'] = 'Modello degli eventi';
$lang['cal_settings'] = 'Configurazioni';
$lang['cal_prev'] = '&laquo; Precedente';
$lang['cal_next'] = 'Prossimo &raquo;';
$lang['cal_categories_updated'] = 'Categorie aggiornate';
$lang['cal_settings_updated'] = 'Configurazioni aggiornate';
$lang['cal_add_event'] = 'Aggiungi evento';
$lang['cal_edit'] = 'Modifica';
$lang['cal_delete'] = 'Cancella';
$lang['cal_areyousure'] = 'Sei sicuro di voler cancellare';
$lang['cal_update_template'] = 'Aggiornamento Modello';
$lang['cal_sunday'] = 'Domenica';
$lang['cal_monday'] = 'Luned&igrave;';
$lang['cal_tuesday'] = 'Marted&igrave;';
$lang['cal_wednesday'] = 'Mercoled&igrave;';
$lang['cal_thursday'] = 'Gioved&igrave;';
$lang['cal_friday'] = 'Venerd&igrave;';
$lang['cal_saturday'] = 'Sabato';
$lang['cal_sun'] = 'Dom';
$lang['cal_mon'] = 'Lun';
$lang['cal_tues'] = 'Mar';
$lang['cal_wed'] = 'Mer';
$lang['cal_thurs'] = 'Gio';
$lang['cal_fri'] = 'Ven';
$lang['cal_sat'] = 'Sab';
$lang['cal_january'] = 'Gennaio';
$lang['cal_february'] = 'Febbraio';
$lang['cal_march'] = 'Marzo';
$lang['cal_april'] = 'Aprile';
$lang['cal_may'] = 'Maggio';
$lang['cal_june'] = 'Giugno';
$lang['cal_july'] = 'Luglio';
$lang['cal_august'] = 'Agosto';
$lang['cal_september'] = 'Settembre';
$lang['cal_october'] = 'Ottobre';
$lang['cal_november'] = 'Novembre';
$lang['cal_december'] = 'Dicembre';
$lang['cal_add'] = 'Aggiorna';
$lang['cal_update'] = 'Aggiungi';
$lang['cal_event'] = 'Evento';
$lang['cal_date'] = 'Data';
$lang['cal_summary'] = 'Sommario';
$lang['cal_details'] = 'Dettaglio';
$lang['cal_more'] = 'altro >>';
$lang['cal_return'] = 'Ritorno';
$lang['cal_to'] = 'a';
$lang['cal_past_events'] = 'Eventi passati';
$lang['cal_upcoming_events'] = 'Eventi futuri';
$lang['cal_any_category'] = 'Qualsiasi categoria';
$lang['cal_show_only_events_in'] = 'Mostra solo gli eventi in';
$lang['cal_filter_by'] = 'Filtra Titolo per <em>(regex)</em>';
$lang['cal_go'] = 'Vai';
$lang['cal_title'] = 'Titolo';
$lang['cal_fromdate'] = 'Dalla data';
$lang['cal_todate'] = 'Alla data';
$lang['cal_update_categories'] = 'Aggiona categorie';
$lang['cal_language'] = 'Lingua';
$lang['cal_updatesettings'] = 'Aggiorna configurazione';
$lang['cal_use_twelve_hour_clock'] = 'Usare il l&#039;orologio a 12 ore nel menu a tendina delle ore?';
$lang['cal_default_category'] = '';
$lang['cal_update_fields'] = 'Aggiorna Campi';
$lang['force_category'] = 'Forza almeno una categoria';
$lang['showpastyears'] = 'Numero di anni passati permessi';
$lang['showfutureyears'] = 'Numero di anni futuri permessi';
$lang['hidesummary'] = 'Deve essere nascosto il campo Sommario';
$lang['hidecontent'] = 'Deve essere nascosto il campo Contenuto';
$lang['category_reminder'] = 'Selezionate una o pi&ugrave; categorie per qusto evento';
$lang['module_example_stylesheet'] = 'Esempio di Foglio di Stile per il Calendario';
$lang['error_permission'] = 'Avete bisogno di permessi appropriati (%s) per accedere a questa funzionalit&agrave;';
$lang['install_postmessage'] = 'Essere sicuri di configurare il permesso &quot;Modify Calendar&quot; per gli utenti che dovranno amministrare gli eventi del calendario.';
$lang['deletetagged'] = 'Cancella eventi selezionati';
$lang['confirmdeletetagged'] = 'Siete sicuri che questi eventi debbano essere cancellati?';
$lang['taggeddeleted'] = 'Gli eventi selezionati sono stati cancellati';
$lang['templates'] = 'Modelli (templates)';
$lang['template_help'] = 'Aiuto per i Modelli';
$lang['file_templates'] = 'Modelli di File';
$lang['addtemplate'] = 'Aggiungi Modello';
$lang['template'] = 'Modello';
$lang['templatenametext'] = 'Nome Modello';
$lang['edittemplate'] = 'Modifica Modello';
$lang['deletetemplate'] = 'Cancella Modello';
$lang['newtemplate'] = 'Nome del Nuovo Modello';
$lang['templatenameexists'] = 'Errore: &egrave; gi&agrave; presente un modello con lo stesso nome. Sceglietene uno diverso';
$lang['templateimported'] = 'Il modello &egrave; stato importato nel database con successo e ora &egrave; installato per l&#039;uso.';
$lang['view_default_stylesheet'] = 'Visualizza Foglio di Stile predefinito';
$lang['filename'] = 'Nome file';
$lang['importtemplate'] = 'Importa Modello';
$lang['template_deleted'] = 'Il Modello &egrave; stato cancellato dal database con successo.';
$lang['updatetemplatesuccess'] = 'Il modello &egrave; stato aggiornato con successo';
$lang['updatetemplatefailure'] = 'Si &egrave; verificato un errore aggiornando il modello';
$lang['settingssaved'] = 'Le impostazioni sono state salvate con successo';
$lang['categorydeleted'] = 'Categoria cancellata';
$lang['categoryupdated'] = 'Categoria aggiornata';
$lang['categoryadded'] = 'Categoria aggiunta';
$lang['eventdeleted'] = 'L&#039;evento &egrave; stato cancellato';
$lang['eventupdated'] = 'Questo evento &egrave; stato aggiornato';
$lang['default_page_error'] = 'Errore: dovete impostare una pagina predefinita per potere utilizzare il modulo Calendar con i pretty URL attivati. Andate nel menu delle impostazioni di Calendar e sceglietene una.';
$lang['time_at'] = 'alle';
$lang['type'] = 'Tipo';
$lang['name'] = 'Nome';
$lang['order'] = 'Ordine';
$lang['fieldadded'] = 'Campo aggiunto con successo';
$lang['fielddeleted'] = 'Campo cancellato';
$lang['fields'] = 'Campi personalizzati';
$lang['textfield'] = 'Campo testo';
$lang['uploadfield'] = 'Campo di caricamento file';
$lang['description'] = '<p>Calendar &egrave; un modulo per visualizzare eventi sulle costre pagine. Quando il modulo &egrave; installato viene aggiunta una Pagina di Amministrazione Calendar nel menu di contenuto, che permette di gestire i vostri eventi.</p>';
$lang['defaultcalendarpage'] = 'Pagina predefinita che contiene Calendar. Deve contenere uno Smarty tag che richiama Calendar. Obbligatorio se usate l&#039;opzione pretty URL.';
$lang['uploaddirectory'] = 'Cartella in posizionare i file caricati';
$lang['uploadfiletypes'] = 'Tipi di file permessi';
$lang['uploadunique'] = 'Verifica nomi di file unici';
$lang['thumb_width'] = 'Larghezza Anteprima';
$lang['thumb_height'] = 'Altezza Anteprima';
$lang['large_width'] = 'Larghezza Immagine Intera';
$lang['large_height'] = 'Altezza Immagine Intera';
$lang['cal_recur_period'] = 'Ripetizione Evento';
$lang['cal_recur_until'] = 'Si ripete fino al';
$lang['help_template'] = '<p><b>Stampa Nome Autore:</b></p>
<code>Autore: {$event.authorname}</code>
';
?>
